:orphan:

Transform can rotate text direction
-----------------------------------
The new `.Text` parameter ``transform_rotates_text`` now sets whether
rotations of the transform affect the text direction.

